@@ -7,7 +7,7 @@
 #include <QMessageBox>
 #include <QFontDatabase>
 
-#define STR_VERSION "0.2.5"
+#define STR_VERSION "0.2.6"
 #define STR_CRLF "<br>"
 #define STR_QT_VERSION "<b>Qt 4.6.2</b>"
 #define STR_COPYRIGHT "Copyright (c) 2010 Avis"
@@ -69,6 +69,8 @@ void SettingsDialog::dumpSettings() const
     nalarmsettings::getInstance().setShowEmpty(ui->chbEmptyVisible->isChecked());
     nalarmsettings::getInstance().setAlarmFilter(ui->cbFilter->currentIndex());
     nalarmsettings::getInstance().setTimeFrame(ui->spinTimeFrame->value());
+
+    nalarmsettings::getInstance().setTransparency(ui->slideTransparency->value());
 }
 
 void SettingsDialog::loadSettings()
@@ -87,6 +89,8 @@ void SettingsDialog::loadSettings()
     ui->cbFilter->setCurrentIndex(nalarmsettings::getInstance().alarmFilter());
     ui->spinTimeFrame->setValue(nalarmsettings::getInstance().timeFrame());
 
+    ui->slideTransparency->setValue(nalarmsettings::getInstance().getTransparency());
+
     ui->spinSize->setValue(wSize);
     ui->spinWidth->setValue(nalarmsettings::getInstance().getWidth());
     {
@@ -135,6 +139,7 @@ void SettingsDialog::showQtAbout()
 
 void SettingsDialog::fontChanged(int aIndex)
 {
+    Q_UNUSED(aIndex);
     QString qs = ui->cbFont->currentText();
     QFont qf (qs);
     qf.setBold(ui->chbBold->isChecked());
